<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Strings for component 'aiplacement_courseassist', language 'id', version '5.0'.
 *
 * @package     aiplacement_courseassist
 * @category    string
 * @copyright   1999 Martin Dougiamas and contributors
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['aidrawerlabel'] = 'Laci konten yang dihasilkan AI';
$string['aiexplain'] = 'Penjelasan AI';
$string['aifeatures'] = 'Fitur AI';
$string['aisummary'] = 'Ringkasan AI';
$string['copy'] = 'Salin';
$string['courseassist:explain_text'] = 'Jelaskan teks';
$string['courseassist:summarise_text'] = 'Merangkum teks';
$string['explain'] = 'Jelaskan';
$string['explain_tooltips'] = 'Buat penjelasan konten halaman yang dibuat oleh AI';
$string['generatefailtitle'] = 'Ada yang salah';
$string['generating'] = 'Hasilkan respons Anda';
$string['nocourseassist'] = 'Ringkasan yang dihasilkan AI tidak tersedia untuk konteks ini.';
$string['pluginname'] = 'Penempatan bantuan kursus';
$string['privacy:metadata'] = 'Pengaya penempatan bantuan kursus tidak menyimpan data pribadi apa pun.';
$string['regenerate'] = 'Hasilkan kembali';
$string['summarise'] = 'Meringkas';
$string['summarise_tooltips'] = 'Buat ringkasan konten halaman yang dibuat oleh AI';
$string['tryagain'] = 'Coba lagi';
